@@ -19,7 +19,7 @@ from . import core
 from . import config 
 import traceback
 from . import util
-
+import os
        
 class Datatable(pd.DataFrame):
     """
@@ -28,7 +28,7 @@ class Datatable(pd.DataFrame):
     
     Datatable is derrived from pandas dataframe. 
     """
-    _metadata = ['meta', 'ID']
+    _metadata = ['meta', 'ID', 'attrs']
 
     def __init__(self, *args, **kwargs):
         
@@ -59,7 +59,6 @@ class Datatable(pd.DataFrame):
             self.generateTableID()
         except:
             self.ID = None
-
     
         if config.AVAILABLE_XARRAY:
             self.to_xarray = self._to_xarray
@@ -68,7 +67,7 @@ class Datatable(pd.DataFrame):
         self.index.name   = 'region'
         
         # print(self.meta)
-        if ('timeformat' in self.meta.keys()) and (self.meta['timeformat'] != '%Y'):
+        if ('_timeformat' in self.meta.keys()) and (self.meta['_timeformat'] != '%Y'):
             self.columns_to_datetime()
 
         self.attrs = self.meta
@@ -231,7 +230,7 @@ class Datatable(pd.DataFrame):
 
     def columns_to_datetime(self):
         self.columns = pd.to_datetime(self.columns, 
-                                      format=self.meta['timeformat'])
+                                      format=self.meta['_timeformat'])
 
     def copy(self, deep=True):
         """
@@ -608,7 +607,22 @@ class Datatable(pd.DataFrame):
         self.ID   =  core._createDatabaseID(self.meta)
         self.meta['ID'] = self.ID
         return self.ID
+    
+    def getTableFilePath(self):
+        source = self.meta['source']
+        fileName = core.generate_table_file_name(self.ID)
+        return os.path.join(config.PATH_TO_DATASHELF, 'database/', source, 'tables', fileName)
 
+        
+    def getTableFileName(self):
+        """
+        For compatibility to windows based sytems, the pipe '|' symbols is replaces
+        by double underscore '__' for the csv filename.
+        """
+        self.generateTableID()
+        
+        return core.generate_table_file_name(self.ID)
+    
     def _update_meta(self):
         self.meta =  core._update_meta(self.meta)
     
@@ -789,7 +803,7 @@ class Datatable(pd.DataFrame):
         else:
             outStr += '=== Datatable ===\n'
         for key in self.meta.keys():
-            if self.meta[key] is not None:
+            if self.meta[key] is not None and not str(self.meta[key]).startswith('_'):
                 outStr += key + ': ' + str(self.meta[key]) + ' \n'
         outStr += super(Datatable, self).__repr__()
         return outStr
@@ -801,7 +815,7 @@ class Datatable(pd.DataFrame):
         else:
             outStr += '=== Datatable ===<br/>\n'
         for key in self.meta.keys():
-            if self.meta[key] is not None:
+            if self.meta[key] is not None and not str(self.meta[key]).startswith('_'):
                 outStr += key + ': ' + str(self.meta[key]) + ' <br/>\n'
         outStr += super(Datatable, self)._repr_html_()
         return outStr
@@ -1682,7 +1696,7 @@ def _try_number_format(x):
         except:
             return x
             
-def read_csv(fileName):
+def read_csv(fileName, load_raw=False):
     
     fid = open(fileName,'r', encoding='utf-8')
     
@@ -1699,15 +1713,41 @@ def read_csv(fileName):
         meta[dataTuple[0]] = _try_number_format(dataTuple[1].strip())
         if "unit" not in meta.keys():
             meta["unit"] = ""
-    df = Datatable(pd.read_csv(fid, index_col=0), meta=meta)
     
-    if ('timeformat' in df.meta.keys()) and (df.meta['timeformat'] != '%Y'):
+    if 'timeformat' in meta.keys():
+         meta['_timeformat'] = meta['timeformat']
+         del meta['timeformat']
+    #print(meta) 
+    
+    df = pd.read_csv(fid)
+    if 'standard_region' not in df.columns:
+        #backward compatibility
+        df = df.set_index(df.columns[0])
+    else:
+        # new datatable
+        if load_raw :
+            
+            df = df.set_index('region')
+            if 'standard_region' in df.columns:
+                df = df.drop('standard_region',axis=1)
+        else:
+            df = df.set_index('standard_region')
+            df = df.drop('region',axis=1)
+    fid.close()
+    df = Datatable(df, meta=meta)
+    if ('_timeformat' in meta.keys()) and (meta['_timeformat'] != '%Y'):
         df.columns_to_datetime()
     else:
         df.columns = df.columns.astype(int)
-
-    fid.close()
-    return df
+    dupl_mask = df.index.duplicated()
+    
+    #removing duplicated entries that might results in different native and standart region definitions
+    if  sum(dupl_mask) > 0:
+        if config.DEBUG:
+            print('Removing duplicated entry')
+        df = df.iloc[~dupl_mask,:]
+    
+    return df#.drop_duplicates()
 
 def read_excel(fileName, 
                sheetNames = None,
@@ -1767,7 +1807,7 @@ def read_excel(fileName,
                                   index   = fileContent.loc[columnIdx+1:, 0], 
                                   columns = fileContent.loc[columnIdx, 1:], 
                                   meta    = metaDict)
-            if ('timeformat' in dataTable.meta.keys()) and (dataTable.meta['timeformat'] != '%Y'):
+            if ('_timeformat' in dataTable.meta.keys()) and (dataTable.meta['_timeformat'] != '%Y'):
                 dataTable.columns_to_datetime()
         
             try:
@@ -1846,9 +1886,9 @@ def read_compact_excel(file_name, sheet_name=None):
                         
                         ID = config.ID_SEPARATOR.join([meta[key] for key in [x for x in config.ID_FIELDS if x in meta.keys()]])
                         print(f'ID could not properly created, fallback to partial ID: {ID}')
-                # if config.DEBUG:
-                    # print(f'meta columns: {meta_columns}')
-                    # print(f'numerical columns: {list(lDf.columns.difference(meta_columns + ["region"]))}')
+                if config.DEBUG:
+                    print(f'meta columns: {meta_columns}')
+                    print(f'numerical columns: {list(lDf.columns.difference(meta_columns + ["region"]))}')
                 numerical_columns = list(lDf.columns.difference(meta_columns + ['region']).astype(int))
                 
                 if ID not in out.keys():
@@ -1866,8 +1906,7 @@ def read_compact_excel(file_name, sheet_name=None):
                     factor = core.conversionFactor(meta['unit'], out[ID].meta['unit'])
                     out[ID].loc[region, numerical_columns] = line.loc[numerical_columns].astype(float) *factor
                     #
-    #%%
-                
+         
     return out
             
         # except:
