@@ -12,6 +12,7 @@ import tqdm
 import time
 import copy
 import types
+
 import traceback
 from collections import defaultdict
 from pathlib import Path
@@ -311,7 +312,6 @@ class Database():
         return table
     
     
-    
     def findExact(self, **kwargs):
         """
         Finds an exact match for the given filter criteria
@@ -335,20 +335,20 @@ class Database():
         Return the file path for a given tableID
         """
         source = self.inventory.loc[ID].source
-        fileName = self._getTableFileName(ID)
+        fileName = core.generate_table_file_name(ID)
         return os.path.join(config.PATH_TO_DATASHELF, 'database/', source, 'tables', fileName)
 
-    def _getTableFileName(self, ID):
-        """
-        For compatibility to windows based sytems, the pipe '|' symbols is replaces
-        by double underscore '__' for the csv filename.
-        """
-        return ID.replace('|','-').replace('/','-') + '.csv'
+    # def _getTableFileName(self, ID):
+    #     """
+    #     For compatibility to windows based sytems, the pipe '|' symbols is replaces
+    #     by double underscore '__' for the csv filename.
+    #     """
+    #     return ID.replace('|','-').replace('/','-') + '.csv'
 
     def _get_source_path(self, sourceID):
         return  os.path.join(config.PATH_TO_DATASHELF, 'database', sourceID)
     
-    def getTable(self, ID):
+    def getTable(self, ID, load_raw=False):
         """
         Method to load the datatable for the given tableID.
         
@@ -367,14 +367,18 @@ class Database():
             # load table from database
             
             filePath = self._getTableFilePath(ID)
-            return read_csv(filePath)
+            table = read_csv(filePath,load_raw)
+            table = table[table.index.notnull()]
+            return table
         
         elif os.path.exists('data'):
-            fileName = self._getTableFileName(ID)
+            fileName = core.generate_table_file_name(ID)
             filePath = os.path.join('data', fileName)
             
             if os.path.exists(filePath):
-                return read_csv(filePath)
+               table = read_csv(filePath,load_raw)
+               table = table[table.index.notnull()]
+               return table
             
                 
         
@@ -399,7 +403,9 @@ class Database():
                 # load table from database
                 
                     filePath = self._getTableFilePath(ID)
-                    return read_csv(filePath)
+                    table = read_csv(filePath,load_raw).drop_duplicates()
+                    table = table[table.index.notnull()]
+                    return table
             except Exception:
                 
                 if config.DEBUG:
@@ -424,7 +430,7 @@ class Database():
         if config.logTables:
             IDs = list()
         res = TableSet()
-        for ID in iterIDs:
+        for ID in tqdm.tqdm(iterIDs):
             table = self.getTable(ID)
             if config.logTables:
                 IDs.append(ID)
@@ -576,8 +582,8 @@ class Database():
             for dataTable in tqdm.tqdm(dataTables):
                 if config.DEBUG:
                     print(dataTable.ID)
-                if cleanTables:
-                    dataTable = util.cleanDataTable(dataTable)
+                # if cleanTables:
+                #    dataTable = util.cleanDataTable(dataTable)
                 
                 if dataTable.isnull().all().all():
                     print('ommiting empty table: ' + dataTable.ID)
@@ -695,7 +701,7 @@ class Database():
         oldID = oldDataTable.meta['ID']
         newID = newDataTable.generateTableID()
         
-        if oldID == newID and (oldDataTable.meta['unit'] == newDataTable.meta['unit']):
+        if oldID == newID:# and (oldDataTable.meta['unit'] == newDataTable.meta['unit']):
             #only change data
             self._addTable( newDataTable)
         else:
@@ -738,7 +744,7 @@ class Database():
                 print(RED + "ID is missing in the inventory")
             valid.append(False)
             
-        fileName = self._getTableFileName(ID)
+        fileName = core.generate_table_file_name(ID)
         tablePath = os.path.join(config.PATH_TO_DATASHELF, 'database', source, 'tables', fileName)
 
         if os.path.isfile(tablePath):
@@ -842,9 +848,9 @@ class Database():
             raise(BaseException('Sorry, data of table {} is needed to be numeric'.format(datatable)))            
             
         # check that spatial index is consistend with defined countries or regions
-        invalidSpatialIDs = datatable.index.difference(mapp.getValidSpatialIDs())
-        if len(invalidSpatialIDs) > 0:
-            raise(BaseException('Sorry, regions in table {}: {} do not exist'.format(datatable, invalidSpatialIDs)))
+        # invalidSpatialIDs = datatable.index.difference(mapp.getValidSpatialIDs())
+        # if len(invalidSpatialIDs) > 0:
+        #     raise(BaseException('Sorry, regions in table {}: {} do not exist'.format(datatable, invalidSpatialIDs)))
         
         # check that the time colmns are years
         from pandas.api.types import is_integer_dtype
@@ -863,14 +869,19 @@ class Database():
         Pools functionality to add table to the database
         """
         
-        ID = datatable.generateTableID()
+        # ID = datatable.generateTableID()
         source = datatable.source()
         datatable.meta['creator'] = config.CRUNCHER
         sourcePath = os.path.join('database', source)
-        filePath = os.path.join(sourcePath, 'tables',  self._getTableFileName(ID))
+        filePath = os.path.join(sourcePath, 'tables',  datatable.getTableFileName())
         if (config.OS == 'win32') | (config.OS == "Windows"):
             filePath = filePath.replace('|','___')
         
+        if 'standard_region' in datatable.columns or 'region' in datatable.columns:
+            datatable = datatable.reset_index().set_index(['region', 'standard_region'])
+            datatable.columns = datatable.columns.astype(int)
+        
+        datatable = util.cleanDataTable(datatable)
         datatable = datatable.sort_index(axis='index')
         datatable = datatable.sort_index(axis='columns')
         
@@ -887,8 +898,8 @@ class Database():
         Added file to git system
         """
         datatable.to_csv(os.path.join(config.PATH_TO_DATASHELF, filePath))
-        
-        self.gitManager.gitAddFile(source, os.path.join('tables', self._getTableFileName(datatable.ID)))
+        ID = datatable.ID
+        self.gitManager.gitAddFile(source, os.path.join('tables', core.generate_table_file_name(ID)))
         
     def _gitCommit(self, message):
         """
@@ -1206,12 +1217,12 @@ class GitRepository_Manager:
         else:
             origin = repo.create_remote("origin", config.DATASHELF_REMOTE + repoName + ".git")
 
-        branch = repo.heads.master
+        branch = repo.active_branch
         origin.push(branch, progress=TqdmProgressPrinter())
 
         # Update references on remote
         origin.fetch()
-        branch.set_tracking_branch(origin.refs.master)
+        branch.set_tracking_branch(origin.refs[0])
     
     def push_to_remote_datashelf(self, repoName):
         """
