@@ -10,6 +10,8 @@ This module contains all relevant tools regarding the use of xarray
 # from datatoolbox import core
 # import datatoolbox as dt
 
+from time import time
+
 from .. import core, config
 import xarray as xr
 import numpy as np 
@@ -44,8 +46,8 @@ def _get_unique_labels(table, dim):
         unique_lables = table.index
     elif dim == table.columns.name:
         unique_lables = table.columns
-    elif dim in table.attrs.keys():
-        unique_lables = [table.attrs[dim]]
+    elif dim in table.meta.keys():
+        unique_lables = [table.meta[dim]]
     else:
         #raise(Exception(f'Dimension {dim} not available'))
         unique_lables = [np.nan]
@@ -66,7 +68,7 @@ def get_dimensions(table_iterable, dimensions):
     return dims
 
 
-
+#%%
     
 def to_XDataSet(tableSet, dimensions=['region', 'time']):
     """
@@ -136,7 +138,7 @@ def to_XDataArray(tableSet, dimensions = ['region', 'time', 'pathway']):
     
     return xData
 
-from time import time
+
 
 def _to_xarray(tables, dimensions, stacked_dims):
     """ 
@@ -175,6 +177,8 @@ def _to_xarray(tables, dimensions, stacked_dims):
         final_dims.append(st_dim)
         
     dims = get_dimensions(tables, xdims)
+    if config.DEBUG:
+        print(dims)
     coords = {x: sorted(list(dims[x])) for x in dims.keys()}
     labels = dict()
     for st_dim, sub_dims in stacked_dims.items():
@@ -210,12 +214,59 @@ def _to_xarray(tables, dimensions, stacked_dims):
     #%%
     return xData
 
+def key_set_to_xdataset(dict_of_data,
+                        dimensions = ['model', 'scenario', 'region', 'time'],
+                        stacked_dims = {'pathway': ('model', 'scenario')}):
+    """ 
+    Returns xarry dataset converted from a dict of pandas dataframes  or dt.TableSet. Differenty variables
+    are stored as key variables. The xarray dimensions (coordiantes) are defined
+    by the provided dimensions. A multi-index for a coordinate can be created
+    by using stacked_dims.
+    
+    Usage:
+    -------
+    dimensions :  Iterable[str]]
+        Dimensions of the shared yarray dimensions / coordinates
+    stacked_dims : Dict[str]]
+        Dictionary of all mutli-index coordinates and their sub-dimensions
+    
+    Returns
+    -------
+    matches : xarray.Dataset + pint quantification
+    """    
+    
+    dim_to_sort = 'variable'
+    sort_dict = dict()
+    for key, table in dict_of_data.items():
+        
+        var = table.meta['variable']
+        
+        if var in sort_dict.keys():
+            sort_dict[var].append(table)
+        else:
+            sort_dict[var] = [table]
+            
+    
+    variables = sort_dict.keys()
+
+    data = list()
+    for variable in variables:
+        tables = sort_dict[variable]
+        
+        xarray = _to_xarray(tables, dimensions, stacked_dims)
+        data.append(xr.Dataset({variable : xarray}))
+        
+    ds = xr.merge(data) 
+
+    
+    return ds
+    
 
 def load_as_xdataset(query_results,
                      dimensions = ['model', 'scenario', 'region', 'time'],
                      stacked_dims = {'pathway': ('model', 'scenario')}):
     """ 
-    Returns a database query result as an xarry dataset. Differenty variables
+    Returns xarry dataset pruduced from a database result. Differenty variables
     are stored as key variables. The xarray dimensions (coordiantes) are defined
     by the provided dimensions. A multi-index for a coordinate can be created
     by using stacked_dims.
