@@ -161,13 +161,13 @@ def scatterIndicatorComparison(tableX, tableY):
     
 def cleanDataTable(dataTable):
     # ensure valid ISO or region IDs
-    invalidSpatialIDs = dataTable.index.difference(mapp.getValidSpatialIDs())
-    if not invalidSpatialIDs.empty:
-        print(
-            f"Removing unknown regions from dataTable {dataTable.meta.get('ID', 'unnamed')}:",
-            ", ".join(invalidSpatialIDs)
-        )
-        dataTable = dataTable.loc[dataTable.index.difference(invalidSpatialIDs)]
+    # invalidSpatialIDs = dataTable.index.difference(mapp.getValidSpatialIDs())
+    # if not invalidSpatialIDs.empty:
+    #     print(
+    #         f"Removing unknown regions from dataTable {dataTable.meta.get('ID', 'unnamed')}:",
+    #         ", ".join(invalidSpatialIDs)
+    #     )
+    #     dataTable = dataTable.loc[dataTable.index.difference(invalidSpatialIDs)]
     
     dataTable = dataTable.dropna(how="all", axis=1).dropna(how="all", axis=0).astype(float)
 
@@ -865,7 +865,6 @@ def open_file(path):
         #     os.system('open -a "Microsoft Excel" ' + self.setup.MAPPING_FILE)
 
 
-
 def shorten_find_output(dataframe):
     return dataframe.reset_index(drop=True).drop(['scenario', 'model', 'category', 'entity', 'source_year', 'source_name', 'unit'], axis=1)
 
